@@ -1,6 +1,4 @@
-"""
-pysat - Python Satellite Data Analysis Toolkit
-==============================================
+"""pysat - Python Satellite Data Analysis Toolkit.
 
 pysat is a package providing a simple and flexible interface for
 downloading, loading, cleaning, managing, processing, and analyzing
@@ -102,14 +100,17 @@ else:
 with Lock(version_filename, 'r', params['file_timeout']) as version_file:
     __version__ = version_file.read().strip()
 
-from pysat import utils
-from pysat._instrument import Instrument
-from pysat._meta import Meta, MetaLabels
 from pysat._files import Files
+from pysat._instrument import Instrument
+from pysat._meta import Meta
+from pysat._meta import MetaHeader
+from pysat._meta import MetaLabels
 from pysat._orbits import Orbits
-from pysat._constellation import Constellation
 from pysat import instruments
+from pysat import utils
 
+# Import constellation separately
+from pysat._constellation import Constellation
 __all__ = ['instruments', 'utils']
 
 # Cleanup
