@@ -18,12 +18,12 @@ from pysat.utils import testing
 class TestCyclicData(object):
     """Unit tests for the `adjust_cyclic_data` function."""
 
-    def setup(self):
+    def setup_method(self):
         """Set up the unit test environment."""
         self.ref_angles = np.array([340.0, 348.0, 358.9, 0.5, 5.0, 9.87])
         return
 
-    def teardown(self):
+    def teardown_method(self):
         """Clean up the unit test environment."""
         del self.ref_angles
         return
@@ -52,19 +52,19 @@ class TestCyclicData(object):
 class TestUpdateLon(object):
     """Unit tests for the `update_longitude` function."""
 
-    def setup(self):
+    def setup_method(self):
         """Set up the unit test environment."""
         self.py_inst = None
         self.inst_time = pysat.instruments.pysat_testing._test_dates['']['']
         return
 
-    def teardown(self):
+    def teardown_method(self):
         """Clean up the unit test environment."""
         del self.py_inst, self.inst_time
         return
 
     @pytest.mark.parametrize("name", ["testing", "testing_xarray",
-                                      "testing2d_xarray", "testmodel"])
+                                      "ndtesting", "testmodel"])
     def test_update_longitude(self, name):
         """Test `update_longitude` successful run."""
 
@@ -106,14 +106,14 @@ class TestCalcSLT(object):
 
     """
 
-    def setup(self):
+    def setup_method(self):
         """Set up the unit test environment for each method."""
 
         self.py_inst = None
         self.inst_time = pysat.instruments.pysat_testing._test_dates['']['']
         return
 
-    def teardown(self):
+    def teardown_method(self):
         """Clean up the unit test environment after each method."""
 
         del self.py_inst, self.inst_time
@@ -200,7 +200,7 @@ class TestCalcSLT(object):
         return
 
     @pytest.mark.parametrize("name", ["testmodel", "testing2d",
-                                      "testing2d_xarray"])
+                                      "ndtesting"])
     def test_lon_broadcasting_calc_solar_local_time(self, name):
         """Test calc_solar_local_time with longitude coordinates."""
 
@@ -217,7 +217,7 @@ class TestCalcSLT(object):
         return
 
     @pytest.mark.parametrize("name", ["testmodel", "testing2d",
-                                      "testing2d_xarray"])
+                                      "ndtesting"])
     def test_lon_broadcasting_calc_solar_local_time_no_mod_multiday(self, name):
         """Test non modulated solar local time output for a 2 day range."""
 
@@ -236,7 +236,7 @@ class TestCalcSLT(object):
         return
 
     @pytest.mark.parametrize("name", ["testmodel", "testing2d",
-                                      "testing2d_xarray"])
+                                      "ndtesting"])
     def test_lon_broadcasting_calc_solar_local_time_no_mod_ref_date(self, name):
         """Test non modulated SLT output for a 2 day range with a ref date."""
 
@@ -257,7 +257,7 @@ class TestCalcSLT(object):
         return
 
     @pytest.mark.parametrize("name", ["testmodel", "testing2d",
-                                      "testing2d_xarray"])
+                                      "ndtesting"])
     def test_lon_broadcasting_calc_solar_local_time_no_mod(self, name):
         """Test SLT calc with longitude coordinates and no modulus."""
 
